[Bug bootstrap/84402] [meta] GCC build system: parallelism bottleneck
rguenth at gcc dot gnu.org
gcc-bugzilla@gcc.gnu.org
Tue Mar 28 08:30:41 GMT 2023
https://gcc.gnu.org/bugzilla/show_bug.cgi?id=84402
--- Comment #60 from Richard Biener <rguenth at gcc dot gnu.org> ---
(In reply to Martin Liška from comment #59)
> (In reply to Andrew Carlotti from comment #58)
> > Since November 2021, there's been a significant regression in the compile
> > time for gimple-match.cc during a bootstrap build (+100% in Stage 2, +73% in
> > Stage 3), with this regression accounting for over 20% of the current total
> > bootstrap time on some aarch64 machines.
>
> Thank for the interesting numbers! Yeah, it's very unfortunate :/
>
> >
> > Most of the change in compile time is due to the following 6 commits (of
> > which one is a performance improvement, and one only regressed the Stage 2
> > build):
> >
> > 7df89377a7ae3906255e38a79be8e5d962c3a0df 24th November 2021
> > Enhance optimize_atomic_bit_test_and to handle truncation. (Hongtao Liu)
> > Stage 2: +27%
> > Stage 3: +33%
>
> This one is btw. a known issue PR108129.
But the revision only sligthly changes the patterns so I'm very curious
how it arrived at 30% slowdown.
Note these (match ..) patterns that are not used from inside match.pd itself
(and do not use other (match ..)) would be perfect candidates to emit
to separate files. Either by explicit syntax or magically where the former
would be easier to cater for in the Makefile.
The "trivial" improvement of course would be to special-case
iterator uses als for (match ...) like we do for (simplify ...) where
we can delay substitution.
More information about the Gcc-bugs
mailing list